@@ -30,20 +30,6 @@ def get_airflow_task_instance(task_run, session=None):
     return ti
 
 
-@provide_session
-def get_airflow_task_instance(task_run, dag_id, session=None):
-    ti = (
-        session.query(TaskInstance)
-        .filter(
-            TaskInstance.dag_id == dag_id,
-            TaskInstance.task_id == task_run.task_af_id,
-            TaskInstance.execution_date == task_run.run.execution_date,
-        )
-        .first()
-    )
-    return ti
-
-
 @provide_session
 def update_airflow_task_instance_in_db(ti, session=None):
     session.merge(ti)
